import { Text, View } from '@tarojs/components'
import { memo, useCallback, useEffect, useMemo, useState } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import { formatPriceDiv } from '@/common/format'
import Taro from '@tarojs/taro'
import LayoutBlock from '@/components/layoutBlock'
import MCheckbox from '@/components/checkbox'
import Tag from '@/components/tag'
import Divider from '@/components/divider'
import NormalButton from '@/components/normalButton'
import ColorKindItem from '../colorKindItem'
import { EnumSaleMode } from '@/common/Enumerate'

type PropsType = {
  obj?: any
}

const DrawerButton = memo<{ isOpen: boolean }>(({ isOpen }) => {
  return (
    <View className={styles.drawerButton}>{isOpen ? <Text className='iconfont icon-shouqi'></Text> : <Text className='iconfont icon-zhankai'></Text>}</View>
  )
})

export default memo((props: PropsType) => {
  console.log('重新渲染 shoppingCartItem');
  const [openDetail, setOpenDetail] = useState(false)

  const handleOpenDetail = () => {
    setOpenDetail((isOpen) => !isOpen)
    
  }

  const [selected, setSelect] = useState<EnumSaleMode>(0)

  const onSelectOrderType = (type: EnumSaleMode) => {
    setSelect(type)
  }

  const [mockList, setMockList] = useState([
    {
      sale_mode: 0,
      list: [
        { id: 0, sale_mode: 0, roll: 5, length: 0, checked: true },
        { id: 1, sale_mode: 0, roll: 6, length: 0, checked: false },
        { id: 2, sale_mode: 0, roll: 7, length: 0, checked: true },
      ],
    },
    {
      sale_mode: 1,
      list: [
        { id: 5, sale_mode: 1, roll: 0, length: 77700, checked: false },
        { id: 6, sale_mode: 1, roll: 0, length: 7600, checked: true },
        { id: 7, sale_mode: 1, roll: 0, length: 400, checked: true },
      ],
    },
    {
      sale_mode: 2,
      list: [
        { id: 8, sale_mode: 2, roll: 0, length: 11100, checked: false },
        { id: 9, sale_mode: 2, roll: 0, length: 8540, checked: true },
      ],
    },
  ])

  const handleChecked = (current) => {
    console.log('handleChecked', current)
    const index = mockList.findIndex(item=>item.sale_mode === selected)
    const tempList = mockList[index].list.map((item) => {
      if (item.id === current.id) {
        item = current
      }
      return item
    })
    setMockList((pre=>{
      return pre.map(item=>{
        if(item.sale_mode === selected){
          item.list = tempList
        }
        return item
      })
    }))
  }
  const handleUnChecked = (current) => {
    const index = mockList.findIndex((item) => item.sale_mode === selected)
    const tempList = mockList[index].list.map((item) => {
      if (item.id === current.id) {
        item = current
      }
      return item
    })
    setMockList((pre) => {
      return pre.map((item) => {
        if (item.sale_mode === selected) {
          item.list = tempList
        }
        return item
      })
    })
  }

  const memoList = useMemo(() => {
    return mockList[selected].list.map((item, index) => {
      return (
        <ColorKindItem
          key={item.id}
          isSelected={item.checked}
          item={item}
          orderType={selected}
          onChecked={handleChecked}
          onUnChecked={handleUnChecked}></ColorKindItem>
      )
    })
  }, [mockList, selected])

  return (
    <LayoutBlock circle customClassName={styles.layout}>
      <MCheckbox customClassName={styles['checkbox']} customTextClass={styles['checkbox--text']} triggerLabel={false}>
        <View className='flex-row justify-between' onClick={handleOpenDetail}>
          <View className={styles.topItem}>
            <View className='flex-row items-center'>
              <View className={styles.topTitle}>灵玉布行</View>
              <Tag type='info' size='normal' circle plain>
                刘思伟
              </Tag>
            </View>
            <View className={styles.summary}>
              <Text>已选 1 种面料，1 个颜色，共 4 条</Text>
            </View>
          </View>
          <DrawerButton isOpen={openDetail} />
        </View>
      </MCheckbox>
      <View className={classnames(styles.detailBox, openDetail ? styles.drawerOpen : styles.drawerClose)}>
        <View className={styles.orderType}>
          <Divider customClassName={styles.line}></Divider>
          <View className={styles.orderTitle}>订单类型</View>
          <View className={styles.orderTypeDetail}>
            <NormalButton
              type={selected === EnumSaleMode.Bulk ? 'primary' : 'info'}
              plain={selected !== EnumSaleMode.Bulk}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(EnumSaleMode.Bulk)}>
              大货
            </NormalButton>
            <NormalButton
              type={selected === EnumSaleMode.Plate ? 'primary' : 'info'}
              plain={selected !== EnumSaleMode.Plate}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(EnumSaleMode.Plate)}>
              剪板
            </NormalButton>
            <NormalButton
              type={selected === EnumSaleMode.BulkCut ? 'primary' : 'info'}
              plain={selected !== EnumSaleMode.BulkCut}
              customStyles={{ padding: '0 50rpx' }}
              circle
              onClick={() => onSelectOrderType(EnumSaleMode.BulkCut)}>
              散剪
            </NormalButton>
          </View>
        </View>
        <View className={styles.orderColor}>
          <Divider customClassName={styles.line}></Divider>
          <View className={classnames(styles.orderTitle, 'justify-between')}>
            <Text>布料颜色</Text>
            <Tag type='danger' size='normal' circle plain={false}>
              大货单位：条
            </Tag>
          </View>
        </View>
        <View className={styles.orderContainer}>{memoList}</View>
      </View>
    </LayoutBlock>
  )
})
